Documentation
¶
Overview ¶
Package register is an interface for service discovery
Index ¶
- Constants
- Variables
- func ExtractSubValue(typ reflect.Type) string
- func ExtractValue(v reflect.Type, d int) string
- func NewContext(ctx context.Context, c Register) context.Context
- type DeregisterOption
- type DeregisterOptions
- type Endpoint
- type Event
- type EventType
- type ListOption
- type ListOptions
- type LookupOption
- type LookupOptions
- type Node
- type Option
- func Addrs(addrs ...string) Option
- func Context(ctx context.Context) Option
- func Logger(l logger.Logger) Option
- func Meter(m meter.Meter) Option
- func Name(n string) Option
- func SetOption(k, v interface{}) Option
- func TLSConfig(t *tls.Config) Option
- func Timeout(t time.Duration) Option
- func Tracer(t tracer.Tracer) Option
- type Options
- type Register
- type RegisterOption
- type RegisterOptions
- type Result
- type Service
- type WatchOption
- type WatchOptions
- type Watcher
Constants ¶
const (
// WildcardDomain indicates any domain
WildcardDomain = "*"
)
Variables ¶
var ( // DefaultRegister is the global default register DefaultRegister Register = NewRegister() // ErrNotFound returned when LookupService is called and no services found ErrNotFound = errors.New("service not found") // ErrWatcherStopped returned when when watcher is stopped ErrWatcherStopped = errors.New("watcher stopped") )
var DefaultDomain = "micro"
DefaultDomain to use if none was provided in options
Functions ¶
func ExtractSubValue ¶
ExtractSubValue exctact *Value from reflect.Type
func ExtractValue ¶
ExtractValue from reflect.Type from specified depth
Types ¶
type DeregisterOption ¶
type DeregisterOption func(*DeregisterOptions)
DeregisterOption option is used to deregister service
func DeregisterAttempts ¶
func DeregisterAttempts(t int) DeregisterOption
DeregisterAttempts specifies deregister atempts count
func DeregisterContext ¶
func DeregisterContext(ctx context.Context) DeregisterOption
DeregisterContext sets the context for deregister method
func DeregisterDomain ¶
func DeregisterDomain(d string) DeregisterOption
DeregisterDomain specifies deregister domain
type DeregisterOptions ¶
type DeregisterOptions struct {
Context context.Context
// Domain the service was registered in
Domain string
// Atempts specify max attempts for deregister
Attempts int
}
DeregisterOptions holds options for deregister method
func NewDeregisterOptions ¶
func NewDeregisterOptions(opts ...DeregisterOption) DeregisterOptions
NewDeregisterOptions returns options for deregister filled by opts
type Endpoint ¶
type Endpoint struct {
Request string `json:"request"`
Response string `json:"response"`
Metadata metadata.Metadata `json:"metadata"`
Name string `json:"name"`
}
Endpoint holds endpoint register info
func ExtractEndpoint ¶
ExtractEndpoint extract *Endpoint from reflect.Method
type Event ¶
type Event struct {
// Timestamp is event timestamp
Timestamp time.Time
// Service is register service
Service *Service
// ID is register id
ID string
// Type defines type of event
Type EventType
}
Event is register event
type ListOption ¶
type ListOption func(*ListOptions)
ListOption option is used to list services
func ListContext ¶
func ListContext(ctx context.Context) ListOption
ListContext specifies context for list method
type ListOptions ¶
ListOptions holds the list options for list method
func NewListOptions ¶
func NewListOptions(opts ...ListOption) ListOptions
NewListOptions returns list options filled by opts
type LookupOption ¶
type LookupOption func(*LookupOptions)
LookupOption option is used to get service
func LookupContext ¶
func LookupContext(ctx context.Context) LookupOption
LookupContext sets the context for lookup method
func LookupDomain ¶
func LookupDomain(d string) LookupOption
LookupDomain sets the domain for lookup
type LookupOptions ¶
type LookupOptions struct {
Context context.Context
// Domain to scope the request to
Domain string
}
LookupOptions holds lookup options
func NewLookupOptions ¶
func NewLookupOptions(opts ...LookupOption) LookupOptions
NewLookupOptions returns lookup options filled by opts
type Node ¶
type Node struct {
Metadata metadata.Metadata `json:"metadata"`
ID string `json:"id"`
Address string `json:"address"`
}
Node holds node register info
type Option ¶
type Option func(*Options)
Option func signature
type Options ¶
type Options struct {
// Tracer used for tracing
Tracer tracer.Tracer
// Context holds external options
Context context.Context
// Logged used for logging
Logger logger.Logger
// Meter used for metrics
Meter meter.Meter
// TLSConfig holds tls.TLSConfig options
TLSConfig *tls.Config
// Name holds the name of register
Name string
// Addrs specifies register addrs
Addrs []string
// Timeout specifies timeout
Timeout time.Duration
}
Options holds options for register
func NewOptions ¶
NewOptions returns options that filled by opts
type Register ¶
type Register interface {
Name() string
Init(...Option) error
Options() Options
Connect(context.Context) error
Disconnect(context.Context) error
Register(context.Context, *Service, ...RegisterOption) error
Deregister(context.Context, *Service, ...DeregisterOption) error
LookupService(context.Context, string, ...LookupOption) ([]*Service, error)
ListServices(context.Context, ...ListOption) ([]*Service, error)
Watch(context.Context, ...WatchOption) (Watcher, error)
String() string
}
Register provides an interface for service discovery and an abstraction over varying implementations {consul, etcd, zookeeper, ...}
func FromContext ¶
FromContext get register from context
func NewRegister ¶
type RegisterOption ¶
type RegisterOption func(*RegisterOptions) // nolint: golint,revive
RegisterOption option is used to register service
func RegisterAttempts ¶
func RegisterAttempts(t int) RegisterOption
RegisterAttempts specifies register atempts count
func RegisterContext ¶
func RegisterContext(ctx context.Context) RegisterOption
RegisterContext sets the register context
func RegisterDomain ¶
func RegisterDomain(d string) RegisterOption
RegisterDomain secifies register domain
func RegisterTTL ¶
func RegisterTTL(t time.Duration) RegisterOption
RegisterTTL specifies register ttl
type RegisterOptions ¶
type RegisterOptions struct {
Context context.Context
Domain string
TTL time.Duration
Attempts int
}
RegisterOptions holds options for register method
func NewRegisterOptions ¶
func NewRegisterOptions(opts ...RegisterOption) RegisterOptions
NewRegisterOptions returns register options struct filled by opts
type Result ¶
type Result struct {
// Service holds register service
Service *Service
// Action holds the action
Action string
}
Result is returned by a call to Next on the watcher. Actions can be create, update, delete
type Service ¶
type Service struct {
Name string `json:"name"`
Version string `json:"version"`
Metadata metadata.Metadata `json:"metadata"`
Endpoints []*Endpoint `json:"endpoints"`
Nodes []*Node `json:"nodes"`
}
Service holds service register info
type WatchOption ¶
type WatchOption func(*WatchOptions)
WatchOption option is used to watch service changes
func WatchContext ¶
func WatchContext(ctx context.Context) WatchOption
WatchContext sets the context for watch method
type WatchOptions ¶
type WatchOptions struct {
// Specify a service to watch
// If blank, the watch is for all services
Service string
// Other options for implementations of the interface
// can be stored in a context
Context context.Context
// Domain to watch
Domain string
}
WatchOptions holds watch options
func NewWatchOptions ¶
func NewWatchOptions(opts ...WatchOption) WatchOptions
NewWatchOptions returns watch options filled by opts